# -*- coding: utf-8 -*-
import dash
import dash_core_components as dcc
import dash_html_components as html

# static data 
hashtags_in_order = ['#Oscars', '#Oscars2016', '#Oscar', '#KCA', '#GOT7', '#ICD', '#UCL', '#OscarsSoWhite', '#Spotlight', '#ArsenalFCB', '#oscars']
counts_in_order = [10886, 4184, 3602, 2435, 1953, 1501, 1471, 1262, 1194, 1029, 1014]

# initialize Dash environment
app = dash.Dash()

# set up an layout
app.layout = html.Div(children=[
    # H1 title on the page
    html.H1(children='Hello Dash for HCDE 530'),

    # a div to put a short description
    html.Div(children='''
        This is a simple Dash application for HCDE 530
    '''),

    # append the visualization to the page
    dcc.Graph(
        id='example-graph',
        figure={
            # configure the data
            'data': [
                # set x to be hashtags, and y to be the counts. We use bars to represent our data.
                {'x': hashtags_in_order, 'y': counts_in_order, 'type': 'bar'},                    
            ],
            # configure the layout of the visualization -- set the title to be Oscar 2016 hashtags
            'layout': {
                'title': 'Top Oscar 2016 hashtags on Feb 23, 2016'
            }
        }
    )
])

if __name__ == '__main__':        
    # start the Dash app
    app.run_server(debug=True)
    

    
