# -*- coding: utf-8 -*-
import dash
import dash_core_components as dcc
import dash_html_components as html
import plotly.graph_objs as go

import sys, time, json, random, logging, codecs
from datetime import datetime


# open the file in utf-8 encoding 
with codecs.open("election2016_20160926_top30_hashtags_hourly_trends.json", "r", encoding="utf-8") as fp:
    data = json.load(fp) # load the content into a dictionary called `data`

# extract top N hashtags (up to 30)    
top = 6
top_hashtags = data["top_hashtags"][:top]

    
# define lines - for each hashtag, we create a line series through go.Scatter with mode 'lines+markers'
series = []
for idx, hashtag in enumerate(top_hashtags):
    series.append(
        go.Scatter(
            x=[datetime(2016, 9, 26, h) for h in range(24)],
            y=data["trends"][hashtag],
            mode='lines+markers',
            name=hashtag               
        ) 
    )       

# initialize Dash app
app = dash.Dash()

# set layout of the page
app.layout = html.Div(children=[

    # set the page heading
    html.H1(children='Line Chart'),

    # set the description underneath the heading
    html.Div(children='''
        A demo to show a line chart.
    '''),
   

    # append the visualization to the page
    dcc.Graph(
        id='example-graph',
        figure={
            # configure the data
            'data': series,
            'layout': {                
                'title': 'Election2016 Hashtag Trends', 
            }
        }
    )   
    
])

    
if __name__ == '__main__':    
    app.run_server(debug=True)