# -*- coding: utf-8 -*-
import dash
import dash_core_components as dcc
import dash_html_components as html
import plotly.graph_objs as go
from plotly import tools

import sys, time, json, random, logging, codecs
from datetime import datetime

if __name__ == '__main__':
    
    # open the file in utf-8 encoding 
    with codecs.open("election2016_20160926_top30_hashtags_hourly_trends.json", "r", encoding="utf-8") as fp:
        data = json.load(fp) # load the content into a dictionary called `data`
    
    # extract top N hashtags (up to 30)    
    top = 6
    top_hashtags = data["top_hashtags"][:top]
    
    # This is how you make a plot that contains multiple subplots.
    # In this case, the number of rows are the number of top hashtags,
    # and the number of cols is one.
    # The x axes are set to be shared so that all plots use the same one
    fig = tools.make_subplots(rows=top, cols=1, shared_xaxes=True)
    
    # Creating the series
    series = []     
    # We define this max_y variable to save the maximum value of possible counts 
    max_y = 0
    for idx, hashtag in enumerate(top_hashtags):
        trace = go.Scatter(
            x=[datetime(2016, 9, 26, h) for h in range(24)],
            y=data["trends"][hashtag],
            mode='lines+markers',
            name=hashtag        
        ) 
        # Unlike the line chart example, we add a line (a trace) to the "fig" directly
        fig.append_trace(trace, idx + 1, 1)     
        
        # Update max_y by comparing max_y with the max of the counts of this hashtag
        max_y = max([max_y] + data["trends"][hashtag])
        
    # This for loop sets all the plots to have the same range of y axes.
    for idx in range(top):        
        fig['layout']["yaxis%d" % (idx + 1)].update(range=[0, max_y + 500])                       
        
    app = dash.Dash()

    app.layout = html.Div(children=[
        html.H1(children='Small Multiples'),

        html.Div(children='''
            A example of small multiples using top hashtag trends on Sept 26, 2016.
        '''),

        dcc.Graph(
            id='example-graph',
            # Instead of having data and layout, now we set the figure through the "fig" we've created above
            figure=fig
        ),
        
       
    ])
    
    app.run_server(debug=True)