# -*- coding: utf-8 -*-
import dash
import dash_core_components as dcc
import dash_html_components as html
import plotly.graph_objs as go

import sys, time, json, random, logging, codecs
from datetime import datetime


# open the file in utf-8 encoding 
with codecs.open("election2016_20160926_top30_hashtags_hourly_trends.json", "r", encoding="utf-8") as fp:
    data = json.load(fp) # load the content into a dictionary called `data`

# extract top N hashtags (up to 30)    
top = 6
top_hashtags = data["top_hashtags"][:top]

    
# define z, which contains the values that we use "heat" to represent
z = []
for idx, hashtag in enumerate(top_hashtags):
    z.append(data["trends"][hashtag])       

# initialize Dash app
app = dash.Dash()

# set layout of the page
app.layout = html.Div(children=[

    # set the page heading
    html.H1(children='Heatmap'),

    # set the description underneath the heading
    html.Div(children='''
        A demo to show a heatmap.
    '''),
   

    # append the visualization to the page
    dcc.Graph(
        id='example-graph',
        figure={
            # configure the data
            'data': [
                # This is how a heatmap is defined -- x is the same as the one we had in the line chart
                # y is different top hashtags this time, and z is the corresponding counts over time
                go.Heatmap(z=z,
                   x=[datetime(2016, 9, 26, h) for h in range(24)],
                   y=top_hashtags)
            ],
            'layout': {                
                'title': 'Election2016 Hashtag Trend Heatmap', 
            }
        }
    )   
    
])

    
if __name__ == '__main__':    
    app.run_server(debug=True)