# -*- coding: utf-8 -*-
import dash
import dash_core_components as dcc
import dash_html_components as html
import plotly.graph_objs as go

import sys, time, json, random, logging, codecs
from datetime import datetime


# open the file in utf-8 encoding 
with codecs.open("election2016_20160926_top30_hashtags_hourly_trends.json", "r", encoding="utf-8") as fp:
    data = json.load(fp) # load the content into a dictionary called `data`

# extract top N hashtags (up to 30)    
top = 30
top_hashtags = data["top_hashtags"][:top]

    
# derive values for scatter points
max_counts = []
min_counts = []
for idx, hashtag in enumerate(top_hashtags):
    max_counts.append(max(data["trends"][hashtag]))
    min_counts.append(min(data["trends"][hashtag]))      

# initialize Dash app
app = dash.Dash()

# set layout of the page
app.layout = html.Div(children=[

    # set the page heading
    html.H1(children='Scatter Plot'),

    # set the description underneath the heading
    html.Div(children='''
        A demo to show a scatter plot.
    '''),
   

    # append the visualization to the page
    dcc.Graph(
        id='example-graph',
        figure={
            # configure the data
            'data': [  
                # This is how we define a scatter plot. Note that it also uses "go.Scatter", 
                # but with the mode to be only "markers"                
                go.Scatter(
                    x=max_counts,
                    y=min_counts,
                    mode='markers',
                    text=top_hashtags,  # This line sets the hashtags as the points' labels.
                    marker={
                        'size': 10,
                        'opacity': 0.8  # By making the points a bit transparent, it can alleviate the occlusion issue
                    }
                )             
            ],
            'layout': {                
                'title': 'Min & Max Hourly Counts of Election2016 Top 30 Hashtags on Sep 26, 2016', 
                # It is always a good practice to have axis labels. 
                # This is especially important in this case as the numbers are not trivial
                'xaxis': {'title': 'Max counts'},
                'yaxis': {'title': 'Min counts'},
            }
        }
    )   
    
])

    
if __name__ == '__main__':    
    app.run_server(debug=True)